Module socket

Module socket 

Structs

BingerUdp
A batch-native UDP socket that automatically selects the most efficient platform syscall for send and receive operations.
Config
Socket configuration for BingerUdp.
PlatformCaps
Reports which platform-optimized syscalls and features are available at compile time.

Functions

platform_capabilities
Returns the PlatformCaps for the current platform and enabled features.